@@ -22,7 +22,7 @@ use Log::Scrubber qw(disable $SCRUBBER scrubber :Carp scrubber_add_scrubber);
 @ISA     = qw(Business::OnlinePayment::HTTPS);
 $me      = 'Business::OnlinePayment::Litle';
 $DEBUG   = 0;
-our $VERSION = '0.954'; # VERSION
+our $VERSION = '0.955'; # VERSION
 
 # PODNAME: Business::OnlinePayment::Litle
 
@@ -1269,16 +1269,13 @@ sub _sftp_connect {
     my ($self,$args,$dir) = @_;
     $self->_die("Missing ftp_username") if ! $args->{'ftp_username'};
     $self->_die("Missing ftp_password") if ! $args->{'ftp_password'};
-    my $more_args = [];
-    push @$more_args, ( -o => 'UserKnownHostsFile=' . $args->{'sftp_hosts_file'} ) if $args->{'sftp_hosts_file'};
     require Net::SFTP::Foreign;
     my $sftp = Net::SFTP::Foreign->new(
         $self->server(),
-        timeout        => $args->{'ftp_timeout'} || 90,
+        timeout  => $args->{'ftp_timeout'} || 90,
         stderr_discard => 1,
-        user           => $args->{'ftp_username'},
-        password       => $args->{'ftp_password'},
-        more           => $more_args,
+        user     => $args->{'ftp_username'},
+        password => $args->{'ftp_password'},
     );
     $sftp->error and $self->_die("SSH connection failed: " . $sftp->error);
 
@@ -1739,7 +1736,7 @@ Business::OnlinePayment::Litle - Business::OnlinePayment::Litle - Vantiv (was Li
 
 =head1 VERSION
 
-version 0.954
+version 0.955
 
 =head1 SYNOPSIS
 
